;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "srfi" "20251012.351"
  "Scheme Requests for Implementation browser."
  '((emacs "25.1"))
  :url "https://github.com/srfi-explorations/emacs-srfi"
  :commit "c8e72733cd4d919d20c0452311390441cf8b6862"
  :revdesc "c8e72733cd4d"
  :keywords '("languages" "util")
  :authors '(("Lassi Kortela" . "lassi@lassi.io"))
  :maintainers '(("Lassi Kortela" . "lassi@lassi.io")))
